API Reference
=============

.. toctree::
  :maxdepth: 2

  monoid
  monad
  monadplus
  continuation
  either
  identity
  lazy
  list
  maybe
  reader
  state
  writer
  mixins
  macros
  operations
  utils
  dsl
